Package: marr
Type: Package
Title: Maximum rank reproducibility
Version: 1.21.0
Date: 2021-05-10
Authors@R: 
    c(person("Tusharkanti", "Ghosh",
           email = "tusharkantighosh30@gmail.com",
           role = c("aut", "cre")),
    person("Max", "McGrath",
           role = c("aut")),
    person("Daisy", "Philtron",
           role = c("aut")),
    person("Katerina", "Kechris",
           role = c("aut")),
    person("Debashis", "Ghosh",
           role = c("aut", "cph")))
Imports: Rcpp, SummarizedExperiment, utils, methods, ggplot2, dplyr,
        magrittr, rlang, S4Vectors
LinkingTo: Rcpp
Depends: R (>= 4.0)
Suggests: knitr, rmarkdown, BiocStyle, testthat, covr
VignetteBuilder: knitr
Encoding: UTF-8
License: GPL (>= 3)
Description: marr (Maximum Rank Reproducibility) is a
          nonparametric approach that detects
          reproducible signals using a maximal
          rank statistic for high-dimensional biological data. 
          In this R package, we implement functions that 
          measures the reproducibility of features per sample
          pair and sample pairs per feature in high-dimensional
          biological replicate experiments. The 
          user-friendly plot functions in this package also plot 
          histograms of the reproducibility of
          features per sample pair and sample pairs per feature.
          Furthermore, our approach also allows the users to select
          optimal filtering threshold values for the
          identification of reproducible features and sample pairs
          based on output visualization checks (histograms). This 
          package also provides the subset of data filtered by 
          reproducible features and/or sample pairs.
biocViews: QualityControl, Metabolomics, MassSpectrometry, RNASeq,
        ChIPSeq
BugReports: https://github.com/Ghoshlab/marr/issues
RoxygenNote: 7.1.1
git_url: https://git.bioconductor.org/packages/marr
git_branch: devel
git_last_commit: 9d1d483
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
NeedsCompilation: yes
Packaged: 2025-10-31 22:35:50 UTC; biocbuild
Author: Tusharkanti Ghosh [aut, cre],
  Max McGrath [aut],
  Daisy Philtron [aut],
  Katerina Kechris [aut],
  Debashis Ghosh [aut, cph]
Maintainer: Tusharkanti Ghosh <tusharkantighosh30@gmail.com>
