# Generated by roxygen2: do not edit by hand

export(Marr)
export(MarrFilterData)
export(MarrPlotFeatures)
export(MarrPlotSamplepairs)
export(MarrProc)
exportClasses(Marr)
exportMethods(MarrAlpha)
exportMethods(MarrData)
exportMethods(MarrFeatureVars)
exportMethods(MarrFeatures)
exportMethods(MarrFeaturesfiltered)
exportMethods(MarrPFeatures)
exportMethods(MarrPSamplepairs)
exportMethods(MarrSamplepairs)
exportMethods(MarrSamplepairsfiltered)
exportPattern('^[[:alpha:]]+')
import(methods)
importClassesFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(Rcpp,evalCpp)
importFrom(Rcpp,sourceCpp)
importFrom(S4Vectors,"metadata<-")
importFrom(S4Vectors,metadata)
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,assays)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,rowData)
importFrom(dplyr,filter)
importFrom(dplyr,mutate_if)
importFrom(dplyr,select)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(magrittr,"%>%")
importFrom(methods,setClassUnion)
importFrom(rlang,.data)
importFrom(utils,combn)
importFrom(utils,head)
importFrom(utils,tail)
useDynLib(marr)
