# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

.seqen <- function(n) {
    .Call('_marr_seqen', PACKAGE = 'marr', n)
}

.reptest2 <- function(x, y) {
    .Call('_marr_reptest2', PACKAGE = 'marr', x, y)
}

.cumsumSS <- function(x) {
    .Call('_marr_cumsumSS', PACKAGE = 'marr', x)
}

.subset_range1 <- function(x, start, end) {
    .Call('_marr_subset_range1', PACKAGE = 'marr', x, start, end)
}

.ssapplySSS <- function(xx) {
    .Call('_marr_sapplySSS', PACKAGE = 'marr', xx)
}

.getSS <- function(maxRank) {
    .Call('_marr_getSS', PACKAGE = 'marr', maxRank)
}

.seqenkhat <- function(n, k) {
    .Call('_marr_seqenkhat', PACKAGE = 'marr', n, k)
}

.sapplykhat <- function(khat, maxRank) {
    .Call('_marr_sapplykhat', PACKAGE = 'marr', khat, maxRank)
}

.RNhatcpp <- function(khat, maxRank) {
    .Call('_marr_RNhatcpp', PACKAGE = 'marr', khat, maxRank)
}

