#' Generic function that returns the Marr sample pairs
#'
#' Given a Marr object, this function returns the
#' Marr sample pairs
#' @rdname MarrSamplepairs
setGeneric(name = "MarrSamplepairs", def = function(object) {
            standardGeneric("MarrSamplepairs")
})

#' Generic function that returns the Marr features
#'
#' Given a Marr object, this function returns the
#' Marr features
#' @rdname MarrFeatures
setGeneric(name = "MarrFeatures", def = function(object) {
            standardGeneric("MarrFeatures")
})

#' Generic function that returns the Marr filtered sample pairs
#'
#' Given a Marr object, this function returns the
#' Marr filtered sample pairs
#' @rdname MarrSamplepairsfiltered
setGeneric(name = "MarrSamplepairsfiltered", def = function(object) {
            standardGeneric("MarrSamplepairsfiltered")
})

#' Generic function that returns the Marr filtered features
#'
#' Given a Marr object, this function returns the
#' Marr filtered features
#' @rdname MarrFeaturesfiltered
setGeneric(name = "MarrFeaturesfiltered", def = function(object) {
            standardGeneric("MarrFeaturesfiltered")
})

#' Generic function that returns the Marr Data
#'
#' Given a Marr object, this function returns the
#' Marr Data
#' @rdname MarrData
setGeneric(name = "MarrData", def = function(object) {
    standardGeneric("MarrData")
})

#' Generic function that returns the Marr P Sample Pairs
#'
#' Given a Marr object, this function returns the
#' Marr P Sample Pairs
#' @rdname MarrPSamplepairs
setGeneric(name = "MarrPSamplepairs", def = function(object) {
    standardGeneric("MarrPSamplepairs")
})

#' Generic function that returns the Marr P Features
#'
#' Given a Marr object, this function returns the
#' Marr P Features
#' @rdname MarrPFeatures
setGeneric(name = "MarrPFeatures", def = function(object) {
    standardGeneric("MarrPFeatures")
})

#' Generic function that returns the Marr Alpha
#'
#' Given a Marr object, this function returns the
#' Marr Alpha
#' @rdname MarrAlpha
setGeneric(name = "MarrAlpha", def = function(object) {
    standardGeneric("MarrAlpha")
})

#' Generic function that returns the Marr Feature Vars
#'
#' Given a Marr object, this function returns the
#' Marr Feature Vars
#' @rdname MarrFeatureVars
setGeneric(name = "MarrFeatureVars", def = function(object) {
    standardGeneric("MarrFeatureVars")
})

