% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllClasses.R
\docType{class}
\name{vectorORNull-class}
\alias{vectorORNull-class}
\title{S4 Class union}
\description{
Class union allowing \code{MarrFeatureVars} slot to be a vector
or NULL
}
